@@ -54,14 +54,14 @@ from DHParser import start_logging, suspend_logging, resume_logging, is_filename
     ZeroOrMore, Forward, NegativeLookahead, Required, CombinedParser, mixin_comment, \
     compile_source, grammar_changed, last_value, matching_bracket, PreprocessorFunc, is_empty, \
     remove_if, Node, TransformerCallable, TransformationDict, transformation_factory, traverse, \
-    remove_children_if, move_fringes, normalize_whitespace, is_anonymous, matches_re, \
+    remove_children_if, move_fringes, normalize_whitespace, is_anonymous, name_matches, \
     reduce_single_child, replace_by_single_child, replace_or_reduce, remove_whitespace, \
     replace_by_children, remove_empty, remove_tokens, flatten, all_of, any_of, \
-    merge_adjacent, collapse, collapse_children_if, transform_content, WHITESPACE_PTYPE, \
+    merge_adjacent, collapse, collapse_children_if, transform_result, WHITESPACE_PTYPE, \
     TOKEN_PTYPE, remove_children, remove_content, remove_brackets, change_name, \
-    remove_anonymous_tokens, keep_children, is_one_of, not_one_of, has_content, apply_if, peek, \
+    remove_anonymous_tokens, keep_children, is_one_of, not_one_of, content_matches, apply_if, peek, \
     remove_anonymous_empty, keep_nodes, traverse_locally, strip, lstrip, rstrip, \
-    transform_content, replace_content_with, forbid, assert_content, remove_infix_operator, \
+    replace_content_with, forbid, assert_content, remove_infix_operator, \
     add_error, error_on, recompile_grammar, left_associative, lean_left, set_config_value, \
     get_config_value, node_maker, access_thread_locals, access_presets, PreprocessorResult, \
     finalize_presets, ErrorCode, RX_NEVER_MATCH, set_tracer, resume_notices_on, \
@@ -70,7 +70,7 @@ from DHParser import start_logging, suspend_logging, resume_logging, is_filename
     has_attr, has_parent, ThreadLocalSingletonFactory, Error, canonical_error_strings, \
     has_errors, ERROR, FATAL, set_preset_value, get_preset_value, NEVER_MATCH_PATTERN, \
     gen_find_include_func, preprocess_includes, make_preprocessor, chain_preprocessors, \
-    pick_from_context, json_dumps, RootNode, get_config_values
+    pick_from_trail, json_dumps, RootNode, get_config_values
 
 
 #######################################################################
@@ -865,7 +865,7 @@ if __name__ == "__main__":
 
     if os.path.exists(grammar_path) and os.path.isfile(grammar_path):
         if not recompile_grammar(grammar_path, script_path, force=False, notify=notify):
-            error_file = base_path + '_ebnf_ERRORS.txt'
+            error_file = base_path + '_ebnf_MESSAGES.txt'
             with open(error_file, encoding="utf-8") as f:
                 print(f.read())
             sys.exit(1)
