@@ -324,7 +324,7 @@ BLOCK_ANONYMOUS_LEAVES = BlockAnonymousLeaves()
 
 def traverse(root_node: Node,
              transformation_table: TransformationTableType,
-             key_func: KeyFunc = key_node_name) -> Node:
+             key_func: KeyFunc = key_node_name) -> RootNode:
     """
     Traverses the syntax tree starting with the given ``node`` depth
     first and applies the sequences of callback-functions registered
@@ -438,6 +438,8 @@ def traverse(root_node: Node,
                 raise AssertionError('An exception occurred when transforming "%s" with %s:\n%s'
                                      % (key, str(call), ae.__class__.__name__ + ': ' + str(ae)))
 
+    if not isinstance(root_node, RootNode):
+        root_node = RootNode(root_node)
     traverse_recursive([root_node])
     return root_node
     # assert transformation_table['__cache__']
