@@ -19,12 +19,11 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-import cProfile as profile
 import fnmatch
 import os
-import pstats
 import sys
 
+
 scriptpath = os.path.dirname(__file__) or '.'
 for path in (os.path.join('..', '..'), '.'):
     fullpath = os.path.abspath(os.path.join(scriptpath, path))
@@ -33,11 +32,12 @@ for path in (os.path.join('..', '..'), '.'):
 
 import DHParser.configuration
 import DHParser.dsl
+from DHParser.error import ERROR
 import DHParser.log
 from DHParser.log import log_parsing_history
 
 
-LOGGING = ''
+LOGGING = 'LOGS'
 
 grammar_path = os.path.join(fullpath, 'LaTeX.ebnf')
 if not DHParser.dsl.recompile_grammar(grammar_path, force=False):
@@ -48,8 +48,9 @@ if not DHParser.dsl.recompile_grammar(grammar_path, force=False):
     sys.exit(1)
 
 
-from LaTeXParser import get_grammar, get_transformer, get_compiler
+from LaTeXParser import get_preprocessor, get_grammar, get_transformer, get_compiler
 
+preprocessor = get_preprocessor()
 parser = get_grammar()
 transformer = get_transformer()
 compiler = get_compiler()
@@ -57,10 +58,10 @@ compiler = get_compiler()
 
 def fail_on_error(src, result):
     if result.error_flag:
-        print(result.as_sxpr())
         for e in result.errors_sorted:
             print(str(e))
-        sys.exit(1)
+        if result.error_flag >= ERROR:
+            sys.exit(1)
 
 
 def tree_size(tree) -> int:
@@ -81,8 +82,10 @@ def tst_func():
             with open(filepath, 'r', encoding='utf-8') as f:
                 doc = f.read()
 
-            print('\n\nParsing document: "%s"' % file)
-            result = parser(doc)
+            print(f'\n\nPreprocessing document: "{file}"')
+            preprocessed, _, source_mapper, _ = preprocessor(doc, file)
+            print(f'\n\nParsing document: "{file}"')
+            result = parser(preprocessed)
             print("Number of CST-nodes: " + str(tree_size(result)))
             # print("Number of empty nodes: " + str(count_nodes(result,
             #                                                 lambda n: not bool(n.result))))
@@ -92,7 +95,7 @@ def tst_func():
                 with open(logs + file[:-4] + '.cst', 'w', encoding='utf-8') as f:
                     f.write(result.as_sxpr(compact=False))
                 print('Saving parsing history')
-                log_parsing_history(parser, os.path.basename(file), html=True)
+                log_parsing_history(parser, os.path.basename(file), as_html=True)
 
             print('\nTransforming document: "%s"' % file)
             fail_on_error(doc, result)
@@ -104,17 +107,19 @@ def tst_func():
                 print('Saving AST')
                 with open(logs + file[:-4] + '.ast', 'w', encoding='utf-8') as f:
                     f.write(result.as_sxpr(compact=True))
-                # with open(logs + file[:-4] + '.tex', 'w', encoding='utf-8') as f:
-                #     f.write(str(result))
+                with open(logs + file[:-4] + '.tex', 'w', encoding='utf-8') as f:
+                    f.write(str(result))
 
             print('\nCompiling document: "%s"' % file)
             output = compiler(result)
             with open(os.path.splitext(filepath)[0] + '.xml', 'w', encoding='utf-8') as f:
-                f.write(output.customized_XML())
+                f.write(output.as_xml())
             with open(os.path.splitext(filepath)[0] + '.sxpr', 'w', encoding='utf-8') as f:
-                f.write(output.serialize(DHParser.configuration.SXPRESSION_SERIALIZATION))
+                f.write(output.serialize('S-expression'))
 
 def cpu_profile(func):
+    import cProfile as profile
+    import pstats
     pr = profile.Profile()
     pr.enable()
     func()
@@ -137,7 +142,7 @@ def mem_profile(func):
 
 if __name__ == "__main__":
     cpu_profile(tst_func)
-    from DHParser import syntaxtree
-#    for k, v in syntaxtree.CALLERS.items():
+    from DHParser import nodetree
+#    for k, v in nodetree.CALLERS.items():
 #        print(k, v)
 
