@@ -11,7 +11,7 @@ import collections
 from functools import partial
 import os
 import sys
-from typing import Tuple, List, Union, Any, Optional, Callable
+from typing import Tuple, List, Union, Any, Optional, Callable, Set
 
 try:
     scriptpath = os.path.dirname(__file__)
@@ -93,10 +93,13 @@ class XMLGrammar(Grammar):
     r"""Parser for a XML source file.
     """
     element = Forward()
-    source_hash__ = "74f6b5811157ab9aa5dd5ffaa0350863"
-    disposable__ = re.compile('BOM$|Misc$|NameStartChar$|NameChars$|CommentChars$|PubidChars$|prolog$|PubidCharsSingleQuoted$|VersionNum$|EncName$|Reference$|CData$|EOF$')
+    source_hash__ = "8aec099040a4deac970f5ad623755b3e"
+    disposable__ = re.compile('BOM$|Misc$|NameStartChar$|NameChars$|CommentChars$|PubidChars$|prolog$|PubidCharsSingleQuoted$|VersionNum$|EncName$|Reference$|CData$|EOF$|tagContent$')
     static_analysis_pending__ = []  # type: List[bool]
     parser_initialization__ = ["upon instantiation"]
+    error_messages__ = {'tagContent': [('', "syntax error in tag-name of opening or empty tag:  {1}")],
+                        'ETag': [('', "syntax error in tag-name of closing tag:  {1}")],
+                        'Attribute': [('', "syntax error in attribute definition:  {1}")]}
     COMMENT__ = r''
     comment_rx__ = RX_NEVER_MATCH
     WHITESPACE__ = r'\s*'
@@ -126,9 +129,10 @@ class XMLGrammar(Grammar):
     AttValue = Alternative(Series(Drop(Text('"')), ZeroOrMore(Alternative(RegExp('[^<&"]+'), Reference)), Drop(Text('"'))), Series(Drop(Text("\'")), ZeroOrMore(Alternative(RegExp("[^<&']+"), Reference)), Drop(Text("\'"))))
     content = Series(Option(CharData), ZeroOrMore(Series(Alternative(element, Reference, CDSect, PI, Comment), Option(CharData))))
     Attribute = Series(Name, dwsp__, Drop(Text('=')), dwsp__, AttValue, mandatory=2)
-    emptyElement = Series(Drop(Text('<')), Name, ZeroOrMore(Series(dwsp__, Attribute)), dwsp__, Drop(Text('/>')))
     ETag = Series(Drop(Text('</')), Name, dwsp__, Drop(Text('>')), mandatory=1)
-    STag = Series(Drop(Text('<')), Name, ZeroOrMore(Series(dwsp__, Attribute)), dwsp__, Drop(Text('>')))
+    tagContent = Series(NegativeLookahead(RegExp('[/!?]')), Name, ZeroOrMore(Series(dwsp__, Attribute)), dwsp__, Lookahead(Alternative(Drop(Text('>')), Drop(Text('/>')))), mandatory=1)
+    STag = Series(Drop(Text('<')), tagContent, Drop(Text('>')))
+    emptyElement = Series(Drop(Text('<')), tagContent, Drop(Text('/>')))
     BOM = Drop(RegExp('[\\ufeff]|[\\ufffe]|[\\u0000feff]|[\\ufffe0000]'))
     ExternalID = Alternative(Series(Drop(Text('SYSTEM')), dwsp__, SystemLiteral, mandatory=1), Series(Drop(Text('PUBLIC')), dwsp__, PubidLiteral, dwsp__, SystemLiteral, mandatory=1))
     doctypedecl = Series(Drop(Text('<!DOCTYPE')), dwsp__, Name, Option(Series(dwsp__, ExternalID)), dwsp__, Drop(Text('>')), mandatory=2)
@@ -141,6 +145,9 @@ class XMLGrammar(Grammar):
     prolog = Series(Option(Series(dwsp__, XMLDecl)), Option(Misc), Option(Series(doctypedecl, Option(Misc))))
     element.set(Alternative(emptyElement, Series(STag, content, ETag, mandatory=1)))
     document = Series(Option(BOM), prolog, element, Option(Misc), EOF, mandatory=2)
+    resume_rules__ = {'tagContent': [re.compile(r'(?=>|\/>)')],
+                      'ETag': [re.compile(r'(?=>)')],
+                      'Attribute': [re.compile(r'(?=>|\/>)')]}
     root__ = TreeReduction(document, CombinedParser.MERGE_TREETOPS)
     
 
@@ -160,7 +167,7 @@ def get_grammar() -> XMLGrammar:
     return grammar
     
 def parse_XML(document, start_parser = "root_parser__", *, complete_match=True):
-    return get_grammar()(document, start_parser, complete_match)
+    return get_grammar()(document, start_parser, complete_match=complete_match)
 
 
 #######################################################################
@@ -172,10 +179,11 @@ def parse_XML(document, start_parser = "root_parser__", *, complete_match=True):
 
 XML_PTYPE = ":XML"
 
+WARNING_AMBIGUOUS_EMPTY_ELEMENT = ErrorCode(205)
+
 ERROR_TAG_NAME_MISMATCH = ErrorCode(2000)
 ERROR_VALUE_CONSTRAINT_VIOLATION = ErrorCode(2010)
 ERROR_VALIDITY_CONSTRAINT_VIOLATION = ErrorCode(2020)
-ERROR_WELL_FORMEDNESS_CONSTRAINT_VIOLATION = ErrorCode(2030)
 
 
 class XMLTransformer(Compiler):
@@ -184,15 +192,15 @@ class XMLTransformer(Compiler):
     As of now, processing instructions, cdata-sections an document-type definition
     declarations are simply dropped.
     """
-
     def __init__(self):
-        super(XMLTransformer, self).__init__()
+        super().__init__()
         self.cleanup_whitespace = True  # remove empty CharData from mixed elements
         self.expendables = {'PI', 'CDSect', 'doctypedecl'}
 
     def reset(self):
         super().reset()
         self.preserve_whitespace = False
+        self.non_empty_tags: Set[str] = set()
 
     def extract_attributes(self, node_sequence):
         attributes = collections.OrderedDict()
@@ -203,18 +211,12 @@ class XMLTransformer(Compiler):
                 attributes[node[0].content] = node[1].content
         return attributes
 
-    def constraint(self, node, condition, err_msg, error_code = ERROR):
-        """If `condition` is False an error is issued."""
-        if not condition:
-            self.tree.new_error(node, err_msg, error_code)
-
     def value_constraint(self, node, value, allowed):
         """If value is not in allowed, an error is issued."""
-        self.constraint(
-            node,
-            value in allowed,
-            'Invalid value "%s" for "standalone"! Must be one of %s.' % (value, str(allowed)),
-            ERROR_VALUE_CONSTRAINT_VIOLATION)
+        if not value in allowed:
+            self.tree.new_error(node,
+                                'Invalid value "%s" for "standalone"! Must be one of %s.' \
+                                % (value, str(allowed)), ERROR_VALUE_CONSTRAINT_VIOLATION)
 
     def on_document(self, node):
         node.name = XML_PTYPE
@@ -268,13 +270,24 @@ class XMLTransformer(Compiler):
         if len(node.children) == 1:
             return self.on_emptyElement(node['emptyElement'])
         stag = node['STag']
+        etag = node['ETag']
         tag_name = stag['Name'].content
-        self.constraint(
-            node,
-            tag_name == node['ETag']['Name'].content,
-            f'Starting tag name "{tag_name}" does not match ending '
-            f'tag name "{node["ETag"]["Name"].content}"',
-            ERROR_WELL_FORMEDNESS_CONSTRAINT_VIOLATION)
+
+        if tag_name != etag['Name'].content:
+            l, c = line_col(self.tree.lbreaks, etag['Name'].pos)
+            self.tree.new_error(stag['Name'],
+                                f'Starting tag name "{tag_name}" does not match ending '
+                                f'tag name "{etag["Name"].content}" at {l}:{c}',
+                                ERROR_TAG_NAME_MISMATCH)
+
+        if tag_name in self.tree.empty_tags \
+                and tag_name not in self.non_empty_tags:  # warn only once!
+            self.tree.new_error(node,
+                                f'Tag-name "{tag_name}" has already been used for an empty-tag '
+                                f'<{tag_name}/> earlier. This is considered bad XML-practice!',
+                                WARNING_AMBIGUOUS_EMPTY_ELEMENT)
+
+        self.non_empty_tags.add(tag_name)
         save_preserve_ws = self.preserve_whitespace
         self.preserve_whitespace |= tag_name in self.tree.inline_tags
         attributes = self.extract_attributes(stag.children)
@@ -292,6 +305,14 @@ class XMLTransformer(Compiler):
             node.attr.update(attributes)
         node.name = node['Name'].content
         node.result = ''
+
+        if node.name in self.non_empty_tags \
+                and node.name not in self.tree.empty_tags:  # warn only once!
+            self.tree.new_error(node,
+                                f'Tag-name "{node.name}" has already been used for a non empty-tag '
+                                f'<{node.name}> ... </{node.name}> earlier. This is considered bad XML-practice!',
+                                WARNING_AMBIGUOUS_EMPTY_ELEMENT)
+
         self.tree.empty_tags.add(node.name)
         return node
 
@@ -436,7 +457,7 @@ if __name__ == "__main__":
 
     if os.path.exists(grammar_path) and os.path.isfile(grammar_path):
         if not recompile_grammar(grammar_path, script_path, force=False, notify=notify):
-            error_file = os.path.basename(__file__).replace('Parser.py', '_ebnf_ERRORS.txt')
+            error_file = os.path.basename(__file__).replace('Parser.py', '_ebnf_MESSAGES.txt')
             with open(error_file, 'r', encoding="utf-8") as f:
                 print(f.read())
             sys.exit(1)
