@@ -32,11 +32,12 @@ from DHParser.nodetree import Node, RootNode, parse_sxpr, parse_xml, flatten_sxp
     flatten_xml, parse_json, ZOMBIE_TAG, EMPTY_NODE, ANY_NODE, next_trail, \
     prev_trail, serialize_trail, generate_content_mapping, map_pos_to_trail, \
     select_trail_if, select_trail, create_trail_match_function, pick_trail, \
-    LEAF_TRAIL, TOKEN_PTYPE, insert_node, markup
+    LEAF_TRAIL, TOKEN_PTYPE, insert_node, markup, content_of, strlen_of
 from DHParser.preprocess import gen_neutral_srcmap_func
 from DHParser.transform import traverse, reduce_single_child, \
     replace_by_single_child, flatten, remove_empty, remove_whitespace
 from DHParser.ebnf import get_ebnf_grammar, get_ebnf_transformer, get_ebnf_compiler
+from DHParser.error import ERROR
 from DHParser.dsl import grammar_provider, create_parser
 from DHParser.error import Error
 from DHParser.parse import RE, Grammar
@@ -99,6 +100,20 @@ class TestParseSxpression:
         flat = flatten_sxpr(sxpr)
         assert flat == '(a (b "  ") (d (e "f") (h "i")))'
 
+    def test_sxpression_w_error(self):
+        tree = RootNode(Node('u', 'XXX').with_pos(0))
+        tree.new_error(tree, 'Fehler, "mein Herr"!', ERROR)
+        assert tree.equals(parse_sxpr('(u "XXX")'))
+        sxpr = tree.as_sxpr()
+        assert sxpr == r'''(u `(err "Error (1000): Fehler, \"mein Herr\"!") "XXX")'''
+        tree2 = parse_sxpr(sxpr)
+        assert tree2.as_sxpr() == r'''(u `(err "Error (1000): Fehler, \"mein Herr\"!") "XXX")'''
+        # When backparsing s-expression-serialized trees, errors are parsed as attributes
+        # but not turned into errors in the error-list of the root-node again:
+        assert not tree2.equals(tree)
+        assert not tree.has_attr()
+        assert tree2.attr['err'] == r'''Error (1000): Fehler, \"mein Herr\"!'''
+        assert not tree2.errors
 
 XML_EXAMPLE = '''<?xml version="1.0" encoding="UTF-8"?>
 <note date="2018-06-14">
@@ -110,6 +125,42 @@ XML_EXAMPLE = '''<?xml version="1.0" encoding="UTF-8"?>
   Some Mixed Content...
 </note>'''
 
+XML_EXAMPLE_2 = '''<TEI xmlns:abb="http://www.abbyy.com/FineReader_xml/FineReader10-schema-v1.xml" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:mwg="http://mwg-digital.badw.de">
+  <teiHeader>
+    <!--<fileDesc>
+      <titleStmt>
+        <title>Die römische Agrargeschichte in ihrer Bedeutung für das Staats- und Privatrecht
+          (digitale Edition)</title>
+        <author>Max Weber</author>
+        <editor>Jürgen Deininger</editor>
+        <editor>Bayerische Akademie der Wissenschaften; wissenschaftliche Betreuung: Edith Hanke
+          (für die digitale Edition)</editor>
+      </titleStmt>
+      <editionStmt>
+        <edition>
+          <date>2021-12-01</date>
+        </edition>
+      </editionStmt>
+      <publicationStmt>
+        <p/>
+      </publicationStmt>
+      <sourceDesc>
+        <p/>
+      </sourceDesc>
+    </fileDesc>
+    <encodingDesc>
+      <p>TEI-XML, UTF-8</p>
+    </encodingDesc>
+    <revisionDesc>
+      <listChange>
+        <change>
+          <date>2021-12-01</date>
+          <name>BAdW</name>
+        </change>
+      </listChange>
+    </revisionDesc>-->
+  </teiHeader>
+</TEI>'''
 
 class TestParseXML:
     def test_roundtrip(self):
@@ -140,6 +191,27 @@ class TestParseXML:
         tree = parse_xml(r'<LINEFEED>\\</LINEFEED>')
         assert tree
 
+    def test_tag_name_mismatch(self):
+        try:
+            _ = parse_xml('<xml><a>xxx</b></xml>', strict_mode=True)
+            assert False, "ValueError because of tag-mismatch expected!"
+        except ValueError as e:
+            assert str(e).find('1:6 - 1:16') >= 0
+        # This will still print an error message!
+        _ = parse_xml('<xml><a>xxx</b></xml>', strict_mode=False)
+
+    def test_non_empty_empty_tags(self):
+        try:
+            _ = parse_xml('<xml><a/><a>content</a></xml>', strict_mode=True)
+        except ValueError as e:
+            assert str(e).find('1:10') >= 0
+        try:
+            _ = parse_xml('<xml><a>content</a><a/></xml>', strict_mode=True)
+        except ValueError as e:
+            assert str(e).find('1:20') >= 0
+        _ = parse_xml('<xml><a/><a>content</a></xml>', strict_mode=False)
+        _ = parse_xml('<xml><a>content</a><a/></xml>', strict_mode=False)
+
     def test_PI_and_DTD(self):
         """PIs <?...> and DTDs <!...> and the like should politely be overlooked."""
         testdata = """<!DOCTYPE nonsense>
@@ -171,6 +243,12 @@ class TestParseXML:
         description = tree.pick('rdf:Description')
         assert description.has_attr('bibtex:title')
 
+    def test_comments(self):
+        tree = parse_xml('<xml><!-- comment --></xml>')
+        assert tree.as_sxpr() == '(xml)'
+        tree = parse_xml(XML_EXAMPLE_2)
+        assert True  # yeah, no endless loop!
+
     def test_serialize_xml(self):
         root = RootNode(parse_xml(XML_EXAMPLE))
         root.string_tags.update({':Text'})
@@ -178,6 +256,7 @@ class TestParseXML:
         assert root.as_xml() == XML_EXAMPLE[XML_EXAMPLE.find('\n') + 1:]
 
 
+
 class TestParseJSON:
     tree = parse_sxpr('(a (b ä) (d (e ö) (h über)))').with_pos(0)
     d = tree.pick('d')
@@ -342,7 +421,7 @@ class TestNode:
                 for node in self.unique_tree.select(ANY_NODE, include_root=True, skip_subtree='f')]
         assert ''.join(tags) == "abdf", ''.join(tags)
 
-    def test_tree_select_context_if(self):
+    def test_tree_select_trail_if(self):
         tree = parse_sxpr(self.unique_nodes_sexpr)
         contexts = []
         for ctx in tree.select_trail_if(lambda ctx: ctx[-1].name >= 'd',
@@ -355,7 +434,7 @@ class TestNode:
             contexts.append(''.join(nd.name for nd in ctx))
         assert contexts == ['af', 'afg', 'ad']
 
-    def test_select_context_with_skipping(self):
+    def test_select_trail_with_skipping(self):
         tree = parse_sxpr('(a (b c) (d e) (f (g h)))')
         check = []
         contexts = []
@@ -372,7 +451,7 @@ class TestNode:
             contexts.append(''.join(nd.name for nd in ctx))
         assert check == contexts == ['a', 'ab', 'ad', 'af']
 
-    def test_tree_select_context(self):
+    def test_tree_select_trail(self):
         tree = parse_sxpr('(A (B 1) (C (X 1) (Y 1)) (B 2))')
         l = [str(nd) for nd in tree.select('B')]
         assert ''.join(l) == '12'
@@ -794,11 +873,11 @@ class TestSerialization:
         data.result = data.result + (Node('empty', ''),)
         assert data.as_xml(empty_tags=empty_tags, strict_mode=False)\
             .replace('\n', '').replace(' ', '') == \
-            "<xml><empty/><empty>not_empty!?</empty><empty></empty></xml>"
+            "<xml><empty/><empty>not_empty!?</empty><empty/></xml>"
 
 
 class TestSegementExtraction:
-    def test_get_context(self):
+    def test_get_trail(self):
         tree = parse_sxpr('(A (F (X "a") (Y "b")) (G "c"))')
         nd_X = tree.pick('X')
         ctx = tree.reconstruct_trail(nd_X)
@@ -871,10 +950,10 @@ class TestPositionAssignment:
         assert (tree['G']['N'].pos, tree['G']['P'].pos) == (1, 5)
 
 
-class TestContextNavigation:
+class TestTrailNavigation:
     tree = parse_sxpr('(A (B 1) (C (D 2) (E 3)) (F 4))')
 
-    def test_prev_context(self):
+    def test_prev_trail(self):
         ctx = self.tree.pick_trail('D')
         c = prev_trail(ctx)
         assert c[-1].name == 'B'
@@ -888,7 +967,7 @@ class TestContextNavigation:
         c = prev_trail(ctx)
         assert c[-1].name == 'B'
 
-    def test_next_context(self):
+    def test_next_trail(self):
         ctx = self.tree.pick_trail('D')
         c = next_trail(ctx)
         assert c[-1].name == 'E'
@@ -902,7 +981,7 @@ class TestContextNavigation:
         c = next_trail(ctx)
         assert c[-1].name == 'C'
 
-    def test_context_mapping(self):
+    def test_content_mapping(self):
         tree = parse_sxpr('(A (B alpha) (C (D beta) (E gamma)) (F delta))')
         cm = generate_content_mapping(tree)
         for i in range(len(tree.content)):
@@ -923,7 +1002,22 @@ class TestContextNavigation:
         ctx, rel_pos = map_pos_to_trail(i, cm)
         assert ctx[-1].name == 'E' and rel_pos == 2
 
-    def test_standalone_select_context_if(self):
+        select, ignore = {'A', 'B', 'D', 'F'}, {'C'}
+        content = content_of(tree, select, ignore)
+        assert content == "alphadelta"
+        assert strlen_of(tree, select, ignore) == len('alphadelta')
+        assert content_of(tree, select, ignore | {'B'}) == "delta"
+        assert strlen_of(tree, select, ignore | {'B'}) == len("delta")
+        assert content_of(tree, select, ignore | {'A'}) == ""
+        assert strlen_of(tree, select, ignore | {'A'}) == 0
+
+        mapping = generate_content_mapping(tree, select, ignore)
+        insert_node(mapping, content.find('delta'),
+                    Node('G', 'omicron'))
+        assert flatten_sxpr(tree.as_sxpr()) == \
+               '(A (B "alpha") (C (D "beta") (E "gamma")) (G "omicron") (F "delta"))'
+
+    def test_standalone_select_trail_if(self):
         start = self.tree.pick_trail('E')
         save = start.copy()
         sequence = []
@@ -931,7 +1025,7 @@ class TestContextNavigation:
                 start, lambda c: True, include_root=True, reverse=True):
             sequence.append(''.join(n.name for n in ctx))
         assert sequence == ['ACE', 'ACD', 'AC', 'AB', 'A']
-        assert save == start  # context passed should not be changed by select_context
+        assert save == start  # trail passed should not be changed by select_trail
 
         start = self.tree.pick_trail('D')
         sequence = []
@@ -940,7 +1034,7 @@ class TestContextNavigation:
             sequence.append(''.join(n.name for n in ctx))
         assert sequence == ['ACD', 'ACE', 'AC', 'AF', 'A']
 
-    def test_standalone_pick_context(self):
+    def test_standalone_pick_trail(self):
         start = self.tree.pick_trail('A', include_root=True)
         anfang = pick_trail(start, LEAF_TRAIL, include_root=True)
         ende = pick_trail(start, LEAF_TRAIL, include_root=True, reverse=True)
@@ -997,6 +1091,10 @@ class TestEvaluation:
         assert tree.evaluate(actions) == -13
 
 
+#class TestStrLenPos:
+
+
+
 class TestMarkupInsertion:
     testdata_1 = '<document>In Charlot<lb/>tenburg steht ein Schloss.</document>'
     testdata_2 = '''<document>
@@ -1004,6 +1102,13 @@ class TestMarkupInsertion:
 <lem>silvae</lem>
 <rdg wit="A">silvae, </rdg>
 </app> glandiferae</document>'''
+    testdata_3 = '''<doc>Am <outer><inner>Anfang</inner> war das Wort</outer>.</doc>'''
+
+    def test_content(self):
+        tree = parse_xml('<p>This is<fn>footnote</fn> a text</p>')
+        assert content_of(tree) == 'This isfootnote a text'
+        assert content_of(tree, ignore='fn') == 'This is a text'
+        assert content_of(tree, select='fn') == 'footnote'
 
     def test_insert_milestone_1(self):
         empty_tags = set()
@@ -1016,7 +1121,9 @@ class TestMarkupInsertion:
         insert_node(tm, i, milestone)
         xml = tree.as_xml(inline_tags={"document"}, string_tags={TOKEN_PTYPE},
                           empty_tags=empty_tags)
-        assert xml == '<document>In <ref type="subj" target="Charlottenburg_S00231"/>Charlot<lb/>tenburg steht ein Schloss.</document>'
+        assert xml == ('<document>In <ref type="subj" '
+                       'target="Charlottenburg_S00231"/>Charlot<lb/>tenburg steht ein '
+                       'Schloss.</document>')
 
     def test_insert_milestone_2(self):
         empty_tags = set()
@@ -1028,7 +1135,9 @@ class TestMarkupInsertion:
         insert_node(tm, m.start(), milestone)
         xml = tree.as_xml(inline_tags={"document"}, string_tags={TOKEN_PTYPE},
                           empty_tags=empty_tags)
-        assert xml == '<document><app n="g"><lem>silvae</lem><ref type="subj" target="silva_glandifera_S01229"/><rdg wit="A">silvae, </rdg></app> glandiferae</document>'
+        assert xml == ('<document><app n="g"><lem>silvae</lem><ref type="subj" '
+                       'target="silva_glandifera_S01229"/><rdg wit="A">silvae, </rdg></app> '
+                       'glandiferae</document>')
 
     def test_insert_markup_1(self):
         empty_tags = set()
@@ -1037,23 +1146,40 @@ class TestMarkupInsertion:
         assert i >= 0
         k = i + len("Charlottenburg")
         tm = generate_content_mapping(tree)
-        markup(tm, i, k, "ref", type="subj", target="Charlottenburg_S00231")
+        markup(tm, i, k, "ref", { 'type':"subj", 'target':"Charlottenburg_S00231"})
         xml = tree.as_xml(inline_tags={"document"}, string_tags={TOKEN_PTYPE},
                           empty_tags=empty_tags)
-        assert xml == '<document>In <ref type="subj" target="Charlottenburg_S00231">Charlot<lb/>tenburg</ref></document>'
+        assert xml == ('<document>In <ref type="subj" '
+                       'target="Charlottenburg_S00231">Charlot<lb/>tenburg</ref> steht ein '
+                       'Schloss.</document>')
 
     def test_insert_markup_2(self):
         empty_tags = set()
         tree = parse_xml(self.testdata_2, string_tag=TOKEN_PTYPE, out_empty_tags=empty_tags)
         m = next(re.finditer(r'silvae,?\s*glandiferae', tree.content))
         tm = generate_content_mapping(tree)
-        markup(tm, m.start(), m.end(), "ref", type="subj", target="silva_glandifera_S01229")
+        markup(tm, m.start(), m.end(), "ref", {'type': "subj", 'target': "silva_glandifera_S01229"})
         xml = tree.as_xml(inline_tags={"document"}, string_tags={TOKEN_PTYPE},
                           empty_tags=empty_tags)
-        assert xml == '<document><ref type="subj" target="silva_glandifera_S01229"><app n="g"><lem>silvae</lem><rdg wit="A">silvae, </rdg></app> glandiferae</ref></document>'
-
-
+        assert xml == ('<document><app n="g"><lem>silvae</lem><ref type="subj" '
+                       'target="silva_glandifera_S01229"><rdg wit="A">silvae, </rdg></ref></app><ref '
+                        'type="subj" target="silva_glandifera_S01229"> glandiferae</ref></document>')
 
+    def test_insert_markup_3(self):
+        empty_tags = set()
+        tree = parse_xml(self.testdata_3, string_tag=TOKEN_PTYPE, out_empty_tags=empty_tags)
+        m = next(re.finditer(r'Anfang war das Wort', tree.content))
+        cm = generate_content_mapping(tree)
+        markup(cm, m.start(), m.end(), "a")
+        assert tree.as_xml(inline_tags={'doc'}, string_tags={':Text'}) == \
+            '<doc>Am <outer><a><inner>Anfang</inner> war das Wort</a></outer>.</doc>'
+        empty_tags = set()
+        tree = parse_xml(self.testdata_3, string_tag=TOKEN_PTYPE, out_empty_tags=empty_tags)
+        m = next(re.finditer(r'Am Anfang war', tree.content))
+        cm = generate_content_mapping(tree)
+        markup(cm, m.start(), m.end(), "a")
+        assert tree.as_xml(inline_tags={'doc'}, string_tags={':Text'}) == \
+            '<doc><a>Am </a><outer><a><inner>Anfang</inner> war</a> das Wort</outer>.</doc>'
 
 
 if __name__ == "__main__":
